Customer class

Classe Customer da documentação oficial Cielo Ecommerce

Constructors

Customer({String? name, String? identity, String? identityType, String? email, String? birthdate, Address? address, DeliveryAddress? deliveryAddress, BillingAddress? billingAddress, String? phone, String? mobile})
Customer.fromJson(Map<String, dynamic> json)
factory

Properties

address Address?
getter/setter pair
billingAddress BillingAddress?
getter/setter pair
birthdate String?
getter/setter pair
deliveryAddress DeliveryAddress?
getter/setter pair
email String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identity String?
getter/setter pair
identityType String?
getter/setter pair
mobile String?
getter/setter pair
name String?
getter/setter pair
phone String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited